@@ -60,7 +60,9 @@ class FreqDict(models.Model):
         lemmas = self.addCategories(lemmas)
         ls = []
         for key in lemmas:
-            cat = SyntacticCategory.objects.get_or_create(pk=int(lemmas[key]['CategoryNum']),defaults={'Label':'<UNK>'})[0]
+            if int(lemmas[key]['CategoryNum']) > 12:
+                continue
+            cat = SyntacticCategory.objects.get(pk=int(lemmas[key]['CategoryNum']))
             ls.append(Lemma(pk=int(key),FreqDict=self,Label=lemmas[key]['Word'],Category=cat,Frequency=int(lemmas[key]['Freq'])))
         Lemma.objects.bulk_create(ls)
 
@@ -68,7 +70,9 @@ class FreqDict(models.Model):
         wfs = self.loadOrthWF()
         wfs = self.loadTransWF(wfs)
         for key in wfs:
-            lem = Lemma.objects.get(pk=int(wfs[key]['IdLemma']))
+            lem = Lemma.objects.filter(pk=int(wfs[key]['IdLemma']))
+            if len(lem) != 1:
+                continue
             wf = WordForm.objects.create(pk=int(key),Lemma = lem,Frequency = int(wfs[key]['Freq']))
             ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[key]['Spellings'])
             wf.Orthographies.add(*ss)
